@@ -41,6 +41,9 @@ public final class DaemonLoader
     private static Method destroy; //@GuardedBy("this")
     private static Method signal; //@GuardedBy("this")
 
+    /**
+     * Prints version information to {@link System#err}.
+     */
     public static void version()
     {
         System.err.println("java version \"" +
@@ -60,6 +63,12 @@ public final class DaemonLoader
                            System.getProperty("commons.daemon.process.parent") + ")");
     }
 
+    /**
+     * Checks whether the given class name can be instantiated with a zero-argument constructor.
+     *
+     * @param className The class name.
+     * @return true if the given class name can be instantiated, false otherwise.
+     */
     public static boolean check(final String className)
     {
         try {
@@ -95,6 +104,11 @@ public final class DaemonLoader
         return true;
     }
 
+    /**
+     * Invokes the wrapped {@code signal} method.
+     *
+     * @return whether the call succeeded.
+     */
     public static boolean signal()
     {
         try {
@@ -110,6 +124,13 @@ public final class DaemonLoader
         return false;
     }
 
+    /**
+     * Loads the given class by name, initializing wrapper methods.
+     *
+     * @param className The class name to load.
+     * @param args arguments for the context.
+     * @return whether the operation succeeded.
+     */
     public static boolean load(final String className, String[] args)
     {
         try {
@@ -168,7 +189,6 @@ public final class DaemonLoader
             }
 
             init    = c.getMethod("init", myclass);
-
             start   = c.getMethod("start");
             stop    = c.getMethod("stop");
             destroy = c.getMethod("destroy");
@@ -176,7 +196,7 @@ public final class DaemonLoader
             try {
                 signal = c.getMethod("signal");
             } catch (final NoSuchMethodException ignored) {
-                // Signalling will be disabled.
+                // Signaling will be disabled.
             }
 
             /* Create a new instance of the daemon */
@@ -227,17 +247,20 @@ public final class DaemonLoader
         return true;
     }
 
+    /**
+     * Invokes the wrapped {@code start} method.
+     *
+     * @return whether the call succeeded.
+     */
     public static boolean start()
     {
         try {
             // Attempt to start the daemon
             start.invoke(daemon);
-
             // Set the availability flag in the controller
             if (controller != null) {
                 controller.setAvailable(true);
             }
-
         } catch (final Throwable t) {
             // In case we encounter ANY error, we dump the stack trace and
             // return false (load, start and stop won't be called).
@@ -247,6 +270,11 @@ public final class DaemonLoader
         return true;
     }
 
+    /**
+     * Invokes the wrapped {@code stop} method.
+     *
+     * @return whether the call succeeded.
+     */
     public static boolean stop()
     {
         try {
@@ -254,7 +282,6 @@ public final class DaemonLoader
             if (controller != null) {
                 controller.setAvailable(false);
             }
-
             /* Attempt to stop the daemon */
             stop.invoke(daemon);
         }
@@ -267,12 +294,16 @@ public final class DaemonLoader
         return true;
     }
 
+    /**
+     * Invokes the wrapped {@code destroy} method.
+     *
+     * @return whether the call succeeded.
+     */
     public static boolean destroy()
     {
         try {
             /* Attempt to stop the daemon */
             destroy.invoke(daemon);
-
             daemon = null;
             controller = null;
         } catch (final Throwable t) {
@@ -287,6 +318,9 @@ public final class DaemonLoader
     private static native void shutdown(boolean reload);
     private static native void failed(String message);
 
+    /**
+     * A DaemonController that acts on the the global {@link DaemonLoader} state.
+     */
     public static class Controller
         implements DaemonController
     {
@@ -295,7 +329,7 @@ public final class DaemonLoader
 
         private Controller()
         {
-            this.setAvailable(false);
+            setAvailable(false);
         }
 
         private boolean isAvailable()
@@ -317,10 +351,10 @@ public final class DaemonLoader
             throws IllegalStateException
         {
             synchronized (this) {
-                if (!this.isAvailable()) {
+                if (!isAvailable()) {
                     throw new IllegalStateException();
                 }
-                this.setAvailable(false);
+                setAvailable(false);
                 DaemonLoader.shutdown(false);
             }
         }
@@ -330,10 +364,10 @@ public final class DaemonLoader
             throws IllegalStateException
         {
             synchronized (this) {
-                if (!this.isAvailable()) {
+                if (!isAvailable()) {
                     throw new IllegalStateException();
                 }
-                this.setAvailable(false);
+                setAvailable(false);
                 DaemonLoader.shutdown(true);
             }
         }
@@ -360,7 +394,7 @@ public final class DaemonLoader
         public void fail(final String message, final Exception exception)
         {
             synchronized (this) {
-                this.setAvailable(false);
+                setAvailable(false);
                 String msg = message;
                 if (exception != null) {
                     if (msg != null) {
@@ -376,6 +410,9 @@ public final class DaemonLoader
 
     }
 
+    /**
+     * A concrete {@link DaemonContext} that acts as a simple value container.
+     */
     public static class Context
         implements DaemonContext
     {
@@ -390,6 +427,11 @@ public final class DaemonLoader
             return daemonController;
         }
 
+        /**
+         * Sets the daemon controller.
+         *
+         * @param controller the daemon controller.
+         */
         public void setController(final DaemonController controller)
         {
             this.daemonController = controller;
@@ -401,7 +443,12 @@ public final class DaemonLoader
             return args;
         }
 
-        public void setArguments(final String[]args)
+        /**
+         * Sets arguments. Note that this implementation doesn't currently make a defensive copy.
+         *
+         * @param args arguments.
+         */
+        public void setArguments(final String[] args)
         {
             this.args = args;
         }
